# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""otfftw module"""


from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_otfftw')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_otfftw')
    _otfftw = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_otfftw', [dirname(__file__)])
        except ImportError:
            import _otfftw
            return _otfftw
        try:
            _mod = imp.load_module('_otfftw', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _otfftw = swig_import_helper()
    del swig_import_helper
else:
    import _otfftw
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

import openturns.base
import openturns.common
import openturns.typ
import openturns.statistics
import openturns.graph
import openturns.func
import openturns.geom
import openturns.diff
import openturns.optim
import openturns.experiment
import openturns.solver
import openturns.algo
import openturns.uncertainty
import openturns.model_copula
import openturns.randomvector
import openturns.dist_bundle1
import openturns.dist_bundle2
import openturns.weightedexperiment
import openturns.classification
import openturns.orthogonalbasis
import openturns.metamodel
import openturns.transformation
import openturns.analytical
import openturns.simulation
import openturns.stattests
import openturns.model_process
class FFTW(openturns.statistics.FFTImplementation):
    """Proxy of C++ OTFFTW::FFTW class."""

    __swig_setmethods__ = {}
    for _s in [openturns.statistics.FFTImplementation]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, FFTW, name, value)
    __swig_getmethods__ = {}
    for _s in [openturns.statistics.FFTImplementation]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, FFTW, name)

    def getClassName(self):
        """
        getClassName(FFTW self) -> OT::String

        Accessor to the object's name.

        Returns
        -------
        class_name : str
            The object class name (`object.__class__.__name__`).
        """
        return _otfftw.FFTW_getClassName(self)


    def transform(self, *args):
        """
        transform(FFTW self, ComplexCollection collection) -> ComplexCollection
        transform(FFTW self, ComplexCollection collection, OT::UnsignedInteger const first, OT::UnsignedInteger const size) -> ComplexCollection

        Perform Fast Fourier Transform (fft).

        Parameters
        ----------
        collection : :class:`~openturns.ComplexCollection` or :class:`~openturns.ScalarCollection`, sequence of float
          Data to transform.

        Returns
        -------
        collection : :class:`~openturns.ComplexCollection`
          The data in Fourier domain.

        Notes
        -----
        The Fast Fourier Transform writes as following:

        .. math::

            {\\rm y_k} = \\sum_{n=0}^{N-1} x_n exp(-2 i \\pi \\frac{kn}{N})

        where :math:`x` denotes the data to be transformed, of size :math:`N`.


        Examples
        --------
        >>> import openturns as ot
        >>> fft = ot.FFT()
        >>> result = fft.transform(ot.Normal(8).getRealization())

        """
        return _otfftw.FFTW_transform(self, *args)


    def inverseTransform(self, *args):
        """
        inverseTransform(FFTW self, ComplexCollection collection) -> ComplexCollection
        inverseTransform(FFTW self, ComplexCollection collection, OT::UnsignedInteger const first, OT::UnsignedInteger const size) -> ComplexCollection

        Perform Inverse Fast Fourier Transform (fft).

        Parameters
        ----------
        collection : :class:`~openturns.ComplexCollection` or :class:`~openturns.ScalarCollection`, sequence of float
          Data to transform.

        Returns
        -------
        collection : :class:`~openturns.ComplexCollection`
            The transformed data.

        Notes
        -----
        The Inverse Fast Fourier Transform writes as following:

        .. math::

            {\\rm y_k} = \\sum_{n=0}^{N-1} \\frac{1}{N} x_n exp(2 i \\pi \\frac{kn}{N})

        where :math:`x` denotes the data, of size :math:`N`, to be transformed.


        Examples
        --------
        >>> import openturns as ot
        >>> fft = ot.FFT()
        >>> collection = ot.ComplexCollection([1+1j,2-0.3j,5-.3j,6+1j,9+8j,16+8j,0.3])
        >>> result = fft.inverseTransform(collection)

        """
        return _otfftw.FFTW_inverseTransform(self, *args)


    def __repr__(self):
        """__repr__(FFTW self) -> OT::String"""
        return _otfftw.FFTW___repr__(self)


    def __str__(self, *args):
        """
        __str__(FFTW self, OT::String const & offset) -> OT::String
        __str__(FFTW self) -> OT::String
        """
        return _otfftw.FFTW___str__(self, *args)


    def __init__(self, *args):
        """
        __init__(OTFFTW::FFTW self) -> FFTW
        __init__(OTFFTW::FFTW self, FFTW other) -> FFTW
        """
        this = _otfftw.new_FFTW(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _otfftw.delete_FFTW
    __del__ = lambda self: None
FFTW_swigregister = _otfftw.FFTW_swigregister
FFTW_swigregister(FFTW)

# This file is compatible with both classic and new-style classes.





#!/usr/bin/env python

from __future__ import print_function
from openturns import *
from otfftw import *
from time import *


myFFTW = FFTW()
print("myFFTW=", myFFTW)
size = 8
data = ComplexCollection(size)
for i in range(size):
    data[i] = (i + 1.0) - 0.2j * (i + 1.0)
print("data=", data)
result = myFFTW.transform(data)
print("result=", result)
print("ref   =", KissFFT().transform(data))
print("back=", myFFTW.inverseTransform(result))
